@@ -36,7 +36,9 @@ def main():
     with GoogleClient(parsed_args.config['client_id'],
                       parsed_args.config['client_secret'],
                       parsed_args.config['refresh_token'],
-                      parsed_args.config['user_agent']) as client:
+                      parsed_args.config.get('request_timeout'),
+                      parsed_args.config['user_agent']
+                      ) as client:
 
         state = {}
         if parsed_args.state:
